**3. Background**

Crop performance is unpredictable due to biotic and abiotic stressors,
such as weather and insect population dynamics, that the crop endures
throughout the growth cycle. In addition to these environmental
stressors other factors such as crop variety (e.g., genetics) and
management affect crop response. Understanding how these stressors
interact to impact crop performance is critical to ensuring adequate
food and fiber production. When all genotypes of a crop respond equally
to changes in environmental factors such as precipitation or
temperature, the system is purely additive and selection of the best
genotypes is relatively simple; the top performing lines are the top
performing lines in all year by location combinations. The response of a
variety in a given environment can then be modeled in an additive
fashion.

Unfortunately, this purely additive model rarely explains crop response,
as many genotypes respond in a non-additive fashion when observed in
different environments. **This non-additive response is known as
genotype by environment interaction (G\*E) and quantifying this is
perhaps the greatest challenge in plant breeding and precision
agriculture**. G\*E is essentially a non-parallel/non-linear response of
two or more genotypes to differing environments or different management
regimes, an is typically described as a mix of non-crossover and
crossover interactions. The inability to quantify G\*E interactions
negatively impacts a breeder’s ability to predict the best variety for
the TPE. Investigation of these G\*E interactions requires that breeders
access data from across multiple scientific disciplines to characterize
all of the controlling factors (e.g., climate, soils, topographic).
Unfortunately, there are currently no simple means to access all of the
data from all of the disciplines without prohibitive time and effort. In
addition, once data are discovered (no small task in itself) researchers
must dedicate significant time and effort to access and manipulate the
data for integration into the plethora of commercial and open source
analysis software commonly used in the plant breeder community. For
instance, Lohr (2014) estimated that data access, processing, and
conversion can be 50-80% of any new scientific discovery effort.

In multi-environment trials (MET), genotype performance varies across
environments leading to variance differences and rank changes among
genotypes (Cooper and Delacy, 1994). For example, year-to-year variation
in temperature and rainfall can affect crop quality (i.e. the yield,
percent oil, starch, and/or protein) more than differences among
different varieties grown at the same location (Bita and Gerats, 2013;
Prasad et al., 2008). Even for a given location, intra-field variations
in properties such as soil moisture or soil depth can have a significant
influence on crop yield and quality. Two primary forms of G\*E are
non-crossover (variance differences) and crossover G\*E (rank changes).
Rank changes complicate crop selection for broad adaptation, there is
not one best genotype for every location.

Genomic selection (GS) was first proposed by Meuwissen et al. (Meuwissen
et al., 2001) to better estimate breeding values based on the
simultaneous use of whole-genome markers. A number of empirical and
theoretical studies suggest that GS could increase genetic gain per unit
of time beyond what is possible with conventional phenotypic selection
(Heffner et al., 2010; Lorenz et al., 2011). In the context of
environmental variability, crop environment accounts for significantly
more variability in the crop characteristics than does incremental
genetic gain, increasing the importance of G\*E investigations anywhere
field data has been collected. However, if tools were available that
could easily characterize and seamlessly integrate environmental data
into analysis software common to the breeding/crop science community
such as R, SAS, GenStat, ASReml, and Python, the rate of genotype to
phenotype mapping would be dramatically accelerated. This project will
provide those tools.

While GS provides an important breakthrough toward a better genotype to
phenotype mapping, an important part of the mapping, the differential
response of genotypes to the environment, i.e., G\*E (van Eeuwijk et
al., 2005), has yet to be included directly into GS approaches. Genomic
predictions have so far been limited to relatively few estimates of
genotype performance with the presumption that they are useful across
all environments, an untested assumption, and one which our approach
will help to answer.

In the context of classical plant breeding, the G\*E issue has been
addressed in several ways (DeLacy et al., 1996). The most common way is
to ignore G\*E in the analysis by assuming it to be random noise.
Another approach is to identify repeatable G\*E patterns in the data by
grouping similar environments targeted by breeding into
mega-environments that minimize G\*E within each mega-environment. A
third, and the most powerful integration of G\*E within quantitative
genetics theory, is to actually consider G\*E as a lack of genetic
correlation between environments (Falconer and Mackay, 1996). Genetic
correlations between environments are obtained by considering
performance in different environments as different correlated traits. We
will configure an analysis system that can easily perform the last two
approaches, simultaneously, which will give the most information
allowing each to be evaluated for time and space predictive
capabilities.

To gain predictive capability, the genetic basis of G\*E can be
investigated by identifying the signature parameters describing the
ambient environmental conditions responsible for G\*E and determining
genotype sensitivity (Denis, 1988; Piepho, 1998) allowing genotype
performance to be characterized as the sum of the main genotype effect
and of the genotype sensitivity to the environmental stress covariate.
As an example, factorial regression has been extended to the
differential response of Quantitative Trait Loci analysis (QTL) in the
biparental mapping case for a few detected QTLs (Boer et al., 2007;
Crossa et al., 1999; Malosetti et al., 2004). Ideally, characterization
of the TPE will allow a breeder to accurately predict genotype
performance in future or as of yet, untested environments within the TPE
as is needed to maintain food security under multiple environmental
stressors.

In order to address the challenges posed by G\*E, breeders often utilize
crop models that incorporate environment data to predict G\*E (Chenu et
al., 2008; Messina et al., 2009). These crop models are often derived
from empirical relationships (although there are several that are
deterministic in nature), developed by extensively studying the behavior
of crop genotypes under a range of growing conditions with the purpose
of predicting the development of a crop and the genesis of the different
yield components. Heslot et al. (2014) demonstrated a method that used
climatic data to initialize a crop model by specifying weather
covariates synchronized with the plant development stage. This method,
an extension of the factorial regression model, utilized molecular
marker data to model G\*E on a genome-wide scale. A machine-learning
algorithm was used to capture non-linear effects and interactions
between predictors. Resulting G\*E predictions were then used to make
breeding decisions for specific adaptations and to identify genotypes
that were stable and exhibit less G\*E for specific environments.
Further, modeling the G\*E for genotypes in untested environments
facilitated characterization of the TPE and understanding of the genetic
control of G\*E. Incorporating weather data through the crop model
significantly increased overall prediction accuracy for yield by 11% and
reduced the coefficient of variability in the estimates by 10%. Jarquin
et al. (2014) proposed a variance components approach where they used
covariance functions to model high dimensional interactions between
markers and environmental covariates (ECs) for wheat and maize, with the
goal to model G\*E by regressing phenotypes on markers and ECs and
partitioning the G\*E. In the Jarquin et al. (2014) model, genetic and
environmental gradients are described using a linear regression on
genetic markers and on ECs. They used 68 ECs related to different crop
developmental stages and compared interactions with main effects and
found that models that included the interaction terms were 17 to 34%
more accurate than models based only on main effects.

Another important application of environmental data is in the field of
precision agriculture. Precision agriculture is a farm management system
that is based on field variability and delivering custom seeding
fertilization, and pesticide rates optimized for that TPE. The goal of
precision agriculture research is to optimize returns on inputs while
preserving resources and minimizing environmental impacts.
Implementation of precision agriculture is dependent on the ability of
growers to manage their crops differentially to achieve the goals of
maximizing yield and profit while simultaneously minimizing
environmental impact. The major obstacle to this is uncertainty of
information relating to the spatial and temporal variation of those
factors that determine yield components and environmental losses (Zhang
et al 2002). Characterization of the environment using climatic and
edaphic data can improve the accuracy of the recommendations for crop
management.

**i. Bridging the GEO and BIO Communities:** The environmental
characteristics most important for understanding G\*E are climate
(precipitation, temperature, solar radiation, wind, and relative
humidity), soil characteristics (soil type, depth, organic matter, sand,
silt, and clay fractions, available water content) and site
characteristics (topography, slope, aspect, elevation). Within the
geoscience domain significant progress has been made in determining how
these factors influence water and chemical movement at sub-field scales
from global scale datasets (Collick et al., 2014; Fuka et al., 2016;
Wagena et al., 2016). In addition, significant progress has been made
towards providing climate data to scientists in data poor locations at
accuracies similar to data rich locations (Auerbach et al., 2016; Fuka
et al., 2014b; Sommerlot et al., 2016). Using these methods, researchers
have been able to characterize how properties such as soil depth and
texture, saturated conductivity and organic carbon vary across what
otherwise appears a uniform field (Moore et al., 1993; Saxton and Rawls,
2006). These sub-field scale variations are exactly what confound G\*E
studies because the variability propagated on the crop by these factors
often elicit a response greater than the intrinsic variability between
crop lines.

Unfortunately, the datasets required to perform the G\*E studies come
from many different scientific domains (e.g., hydrology, soil
physics/science, atmospheric science, etc), each with their own unique
data standards and formats. Reaching across these disciplines, with
their different vocabularies, cultures and underlying assumptions is an
ongoing challenge. A solution that simplifies this process already
exists in the geoscience domain for the hydrology use case. The
challenge is to extend this environment in a cross-disciplinary setting
through a technology we will henceforth refer to as the G\*E
Alignment-Engine.
