**4.5 *Obj. 5.* Develop *Genomic Database Alignment:*** Traditionally,
plant breeders generate new populations from crosses between different
parental lines and then select and test them in a well-defined region
over several years. With the advent of inexpensive whole genome
genotyping and its use in genomic selection, there is the ability to
predict the performance of a genotype in a region prior to actually
growing it in formal field trials. G\*E is still a challenge because of
the complexity of environmental conditions that affect plant growth are
not easily accounted for. In this project, we will work to enable the
plant breeder to use environmental characteristics to predict a
significant portion of the G\*E effects (Heslot et al., 2014), by
automating four methods used to increase the efficiency of plant
breeding:

1.  *Align climatic and soil information with the genotypes and
    phenotypes in crop models to increase the prediction accuracy of
    breeding values*

2.  *Provide predicted ambient environment data for use* *in
    statistical* *predictive models with* *plant genotypes to predict
    their adaptation to those climatic ranges and soil characteristics
    prior to testing those genotypes*

3.  *Identifying similar environments globally allowing the breeder to
    predict regions where particular genotypes are adapted, even if that
    crop is not currently grown there*

4.  *Perform climate change* *what if scenarios* *to allow the breeder
    to develop varieties that are better adapted to future climates for
    a given location or to predict future locations where existing
    varieties should do well*

To be successful for prediction, our approach focusing on the genetic
basis of G\*E will use genome-wide markers and include numerous
weather/climate covariates at the same time. Because response and
development curves are often exponential or ‘S’ shaped (van Eeuwijk et
al., 2005), the framework will accommodate non-linear responses of QTL
to the environment variables using a machine-learning algorithm. This
framework will enable the modeling of G\*E at the allele level focusing
on QTL by environment interaction (Q\*E). We will explicitly model
whole-genome markers and their differential response to the environment
in the GS context to better understand the genetic architecture of G\*E
(van Eeuwijk et al., 2005).

There are several online plant databases including GrainGenes, Gramene,
MaizeDB, PLEXdb, GRIN however, the most comprehensive databases that
currently house both phenotype and genotype data are The Triticeae
Toolbox (T3) (*https://triticeaetoolbox.org*) and Cassavabase
(*http://www.cassavabase.org*). T3 is the database web site for the data
generated by the National Institute for Food and Agriculture (NIFA) of
the USDA-funded *Triticeae Coordinated Agricultural Project* (CAP). T3
stores SNP, phenotypic, and pedigree data from wheat and barley
germplasm produced by plant breeders. The purpose is to integrate DNA
marker and sequence data with traditional phenotypic data to provide
access to predictive analyses for mapping genotype to phenotype and
enabling breeders to select on marker data alone. A new plant genomics
database recently funded by the Bill and Melinda Gates Foundation is the
GOBII project (*http://gobiiproject.org*, collaborator Kelly Robbins,
Director of GOBII) to develop and implement genomic data management
systems to increase the efficiency of public sector breeding programs
and increased rates of genetic gain. The GOBII genomic data management
systems will include databases, imputation systems, and decision support
tools for plant breeders and focus on major crops (rice, wheat, maize,
sorghum and chickpea) at three international centers; The International
Rice Research Institute, the International Center for Wheat and Maize
Research, and the International Crops Research Institute for the
Semi-Arid Tropics. GOBII will be designed to manage very large volumes
of data and have common ISO interface allowing the G\*E Alignment-Engine
to access and align genomic data with the environment data.

The T3 database website includes an open web enabled interface to
donated plant breeder field studies which include temporal, locational,
phenotypic and pedigree metadata, and trial results in a format that the
G\*E Alignment-Engine can easily adapt. For GOBII hosted datasets, this
project team will be able to work directly with the GOBII development
team to integrate a data export utility into their common ISO interface
for simple integration.

**4.6 *Obj. 6. Semantics Alignment:*** Terminology, metadata standards,
and data formats all vary greatly between scientific communities. Even
within a discipline, agreement about the meaning of terms can vary
greatly between different communities within that larger group. As a
simple example, the term “clay” can imply a soil separate, i.e. the
mineral soil particles less than 0.002 millimeter in diameter, or a soil
textural class, i.e. soil material that is 40 percent or more clay, less
than 45 percent sand, and less than 40 percent silt. Moreover, different
disciplines are currently in different stages of semantic development -
ranging from having comprehensive standards with well-adopted
terminologies, keyword sets or ontologies to extremely heterogeneous
non-standardized data without underlying semantic or even syntactic
agreement. Even when disciplines have coalesced around a suite of data
formats, metadata standards, vocabularies and/or ontologies; terms and
fields in these resources need to be mapped to those in use in other
fields since semantic heterogeneity is a fundamental issue with language
in general and experts within one discipline are unlikely to be familiar
with the detailed context that governs language use by experts in other
fields. This is one of the factors that currently make
cross-disciplinary data discovery and assessment difficult and time
consuming.

To mitigate this issue, this project will begin to develop the mappings
required to make geoscience data more discoverable and accessible within
systems that are tailored for the plant breeder/agronomic community;
while making genomics data more discoverable and accessible within the
geoscience community. Analysis of the fields within community metadata
models will determine what components are in common and which are in
need of refinement or definition. Issues of scale and level of
description will also be assessed with an eye towards forming core model
mappings between catalogs and data sets as defined in the G\*E and those
within geoscience communities, but allows room for extension into other
biological communities, with varying nuances between each. This core
model and its extensions will be mapped to metadata standards in each
discipline as appropriate (e.g., ISO 19115 family in GEO).

**4.7 *Obj. 7*. *Team and Community Use Case Scenarios:*** To
demonstrate the utility of the G\*E Alignment-Engine, as well as to
benchmark the resulting product capabilities, a series of use cases will
be implemented. We begin by duplicating existing previously published
G\*E studies; measuring the time to accomplish the data discovery and
acquisition tasks both with and without the G\*E Alignment-Engine, thus
establishing a process efficiency metric. Beyond these initial use
cases, community survey data, discussed in ***Obj. 1,*** will provide a
series of additional G\*E use cases which will demonstrate the resulting
capabilities of the cyberinfrastructure to accelerate new discovery.
